@@ -76,9 +76,10 @@ class RESTClient(RESTAssertion):
                  auth_basic: bool = False,
                  auth_uri: str = '',
                  auth_payload: dict = None,
-                 logger_enabled: bool = False):
+                 logger_enabled: bool = True):
 
         # Enable/disable logger
+        self.logger = logger
         logger.disabled = not logger_enabled
 
         # Credentials and settings for api url
@@ -180,6 +181,8 @@ class RESTClient(RESTAssertion):
             self.header = self.get_auth_header(header=custom_header)
         elif self.auth_basic:
             self.auth_basic = self._auth_basic()
+        elif custom_header:
+            self.header = custom_header
 
         # Make full url to use in request
         link = self.requested_url(url)
@@ -227,8 +230,6 @@ class RESTClient(RESTAssertion):
                 elif files:
                     files_header = self.header.copy()
                     del files_header['Content-Type']
-                    if custom_header:
-                        files_header = custom_header
 
                     logger.debug(f'Headers={files_header}, '
                                  f'Cookies={cookies}, '
@@ -248,7 +249,6 @@ class RESTClient(RESTAssertion):
                     logger.debug(f'Header={self.header}, '
                                  f'Cookies={cookies}, '
                                  f'Timeout={request_timeout}')
-                    logger.info('PAYLOAD:\n' + json.dumps(data, indent=4))
 
                     response = requests.request(method=method,
                                                 url=link,
